#
# Rules.make - make rules for diplomovka-text
#              This file is included by 'make' from Makefile
#
# Developed by Lubomir Host 'rajo' <rajo AT platon.sk>
# Copyright (c) 2005 Platon SDG, http://platon.sk/
# Licensed under terms of GNU General Public License.
# All rights reserved.
#
# $Platon: Platon.SK/office/_templates/Rules.make,v 1.16 2005/04/19 17:07:13 rajo Exp $
#

# Other programs configured automaticaly:
BUILD_STRUCT = $(TOP_DIR)/_scripts/build-struct
CREATE_DOC   = $(TOP_DIR)/_scripts/create-document

TEX_COMPILER             = $(LATEX)
TEX_COMPILER_BATCH       = $(LATEX) -interaction=batchmode
PDFTEX_COMPILER          = $(PDFLATEX)
PDFTEX_COMPILER_BATCH    = $(PDFLATEX) -interaction=batchmode

# TEX_COMPILER             = $(TEX)
# TEX_COMPILER_BATCH       = $(TEX) -interaction=batchmode
# PDFTEX_COMPILER          = $(PDFTEX)
# PDFTEX_COMPILER_BATCH    = $(PDFTEX) -interaction=batchmode

ifndef PLATON_STYLE
PLATON_STYLE = $(TOP_DIR)/_templates/platon-core.sty $(TOP_DIR)/_templates/platon.sty
endif

DEPEND_all = Makefile \
			 ps__OUTPUT \
			 pdf_OUTPUT \
			 $(PLATON_STYLE) \
			 $(TOP_DIR)/_templates/platon-logo.eps \
			 $(TOP_DIR)/_templates/platon-logo.png \
			 $(IMAGES) \
			 $(DEPEND)
export TOP_DIR
export DEPEND_all

ifdef ps__OUTPUT
export ps__OUTPUT
OUTPUT := $(ps__OUTPUT)
endif # ifdef ps__OUTPUT

ifdef pdf_OUTPUT
export pdf_OUTPUT
OUTPUT := $(OUTPUT) $(pdf_OUTPUT)
endif # ifdef pdf_OUTPUT

ifdef OUTPUT
export OUTPUT
endif # ifdef OUTPUT

ps__INPUT    = $(patsubst %.ps,%.tex,$(ps__OUTPUT))
pdf_INPUT    = $(patsubst %.pdf,%.tex,$(pdf_OUTPUT))
export ps__INPUT
export pdf_INPUT

DVI_ps__OUTPUT    = $(patsubst %.ps,%.dvi,$(ps__OUTPUT))
DVI_pdf_OUTPUT    = $(patsubst %.pdf,%.dvi,$(pdf_OUTPUT))
DVI_OUTPUT        = $(DVI_ps__OUTPUT) $(DVI_pdf_OUTPUT)

ps__OUTPUT_first  = $(patsubst %,.first.%,$(ps__OUTPUT))
pdf_OUTPUT_first  = $(patsubst %,.first.%,$(pdf_OUTPUT))
OUTPUT_first      = $(ps__OUTPUT_first)

ps__OUTPUT_second = $(patsubst %,.second.%,$(ps__OUTPUT))
pdf_OUTPUT_second = $(patsubst %,.second.%,$(pdf_OUTPUT))
OUTPUT_second     = $(ps__OUTPUT_second)

ps__OUTPUT_third  = $(patsubst %,.third.%,$(ps__OUTPUT))
pdf_OUTPUT_third  = $(patsubst %,.third.%,$(pdf_OUTPUT))
OUTPUT_third      = $(ps__OUTPUT_third)

ifdef APPEND_DIRNAME
ifdef PREFIX
PREFIX            := $(PREFIX)-$(shell basename `pwd`)
else
PREFIX            := $(shell basename `pwd`)
endif # ifdef PREFIX
endif # ifdef APPEND_DIRNAME


ifdef PREFIX
prefix_ps__OUTPUT = $(patsubst %,$(PREFIX)-%,$(ps__OUTPUT))
prefix_pdf_OUTPUT = $(patsubst %,$(PREFIX)-%,$(pdf_OUTPUT))
endif # ifdef PREFIX

.SUFFIXES:

#
# Now create target `all'
#
# With variables $(ps__OUTPUT) and $(pdf_OUTPUT) you can customize,
# which type of output you will create.
#
ifdef ps__OUTPUT # {{{
ifdef PREFIX
all: ps-subdir ps-prefixed-output
else
all: ps-subdir
endif # ifdef PREFIX
endif # }}} ifdef ps__OUTPUT

ifdef pdf_OUTPUT # {{{
ifdef PREFIX
all: pdf-subdir pdf-prefixed-output
else
all: pdf-subdir
endif # ifdef PREFIX

ifdef ps__OUTPUT # {{{
ifdef PREFIX
all: ps-subdir pdf-subdir ps-prefixed-output pdf-prefixed-output
	@echo 'PREFIX = "$(PREFIX)"'
else
all: ps-subdir pdf-subdir
endif # ifdef PREFIX
endif # }}} ifdef ps__OUTPUT

endif # }}} ifdef pdf_OUTPUT
# end of taget `all'


ps-subdir:
	-@$(BUILD_STRUCT) "PostScript" \
		&& $(MAKE) TOP_DIR=$(TOP_DIR)/.. -C PostScript PostScript

pdf-subdir:
	-@$(BUILD_STRUCT) "PDF" \
		&& $(MAKE) TOP_DIR=$(TOP_DIR)/.. -C PDF PDF


PostScript: $(ps__OUTPUT_first) $(ps__OUTPUT_second) $(ps__OUTPUT_third) $(DVI_ps__OUTPUT) $(ps__OUTPUT)

PDF: $(pdf_OUTPUT)

ifdef PREFIX # {{{
ps-prefixed-output:
	@-for file in $(ps__OUTPUT); do \
		echo "ln -f 'PostScript/$$file' '$(PREFIX)-$$file'"; \
		ln -f "PostScript/$$file" "$(PREFIX)-$$file" \
		|| cp -f "PostScript/$$file $(PREFIX)"; \
	 done

pdf-prefixed-output:
	@-for file in $(pdf_OUTPUT); do \
		echo "ln -f 'PDF/$$file' '$(PREFIX)-$$file'"; \
		ln -f "PDF/$$file" "$(PREFIX)-$$file" \
		|| cp -f "PDF/$$file $(PREFIX)"; \
	 done
endif # }}} ifdef PREFIX

%.ps: %.dvi $(ps__OUTPUT_first) $(ps__OUTPUT_second) $(ps__OUTPUT_third)
	$(DVIPS) -o $@ $<

%.pdf: $(pdf_OUTPUT_first) $(DEPEND_all)
	@file="`echo '$@'`"; \
	echo "$(PDFTEX_COMPILER) $${file%.pdf}.tex"; \
	$(PDFTEX_COMPILER) $${file%.pdf}.tex

%.dvi: .third.%.ps

.third.%.ps: %.tex $(DEPEND_all) .second.%.ps
	$(TEX_COMPILER) $< \
		&& touch $@

.second.%.ps: .first.%.ps
	@file="`echo '$@' | sed 's/^.second.//g;'`"; \
	echo "$(TEX_COMPILER_BATCH) $${file%.ps}.tex"; \
	$(TEX_COMPILER_BATCH) $${file%.ps}.tex \
		&& touch $@
	
.first.%.pdf: %.tex
	$(PDFTEX_COMPILER_BATCH) $< \
		&& touch $@

.first.%.ps:
	@file="`echo '$@' | sed 's/^.first.//g;'`"; \
	echo "$(TEX_COMPILER_BATCH) $${file%.ps}.tex"; \
	$(TEX_COMPILER_BATCH) $${file%.ps}.tex \
		&& touch $@ || (cat $${file%.ps}.log; exit 1 )

view: 
	for i in $(OUTPUT); do \
		test -f "$$i" && $(GV) $$i & \
	done

#
# A rule to do nothing
#
dummy:

documents: doc

ifdef SUBDIRS

doc: doc-subdirs all

subdir-list-doc = $(sort $(patsubst %,_subdir_doc_%,$(SUBDIRS)))
doc-subdirs: dummy $(subdir-list-doc)

$(subdir-list-doc) : dummy
	@if [ -d "$(patsubst _subdir_doc_%,%,$@)" ]; then \
		echo -en "[32;1mMaking documents in directory [35;1m'$(patsubst _subdir_doc_%,%,$@)'[0m"; echo; \
		$(MAKE) -C $(patsubst _subdir_doc_%,%,$@) doc; \
		echo -en "[32;1mMake in directory [35;1m'$(patsubst _subdir_doc_%,%,$@)'[32;1m done.[0m"; echo; \
	else \
		echo -en "[31;1mSkipping nonexistent directory [35;1m'$(patsubst _subdir_doc_%,%,$@)'[0m"; echo; \
	fi
		

else

doc: all
	
endif # ifdef SUBDIRS


# Clean {{{

#
# A rule to make clean in subdirectories
#
ifdef SUBDIRS

clean: clean-subdirs clean-tex-logs clean-graphs clean-postscript clean-pdf
	-rm -f .first.* .second.* .third.* core core.* missfont.log

subdir-list-clean = $(sort $(patsubst %,_subdir_clean_%,$(SUBDIRS)))
clean-subdirs: dummy $(subdir-list-clean)

$(subdir-list-clean) : dummy
	@if [ -d "$(patsubst _subdir_clean_%,%,$@)" ]; then \
		echo -en "[32;1mCleaning documents in directory [35;1m'$(patsubst _subdir_clean_%,%,$@)'[0m"; echo; \
		$(MAKE) -C $(patsubst _subdir_clean_%,%,$@) clean; \
		echo -en "[32;1mClean in directory [35;1m'$(patsubst _subdir_clean_%,%,$@)'[32;1m done.[0m"; echo; \
	else \
		echo -en "[31;1mSkipping nonexistent directory [35;1m'$(patsubst _subdir_clean_%,%,$@)'[0m"; echo; \
	fi

else

clean:               clean-tex-logs clean-graphs clean-postscript clean-pdf
	-rm -f .first.* .second.* .third.* core core.*

endif # ifdef SUBDIRS

ifdef PREFIX
clean-postscript:
	-rm -rf PostScript/
	-rm -f $(prefix_ps__OUTPUT)

clean-pdf:
	-rm -rf PDF/
	-rm -f $(prefix_pdf_OUTPUT)
else
clean-postscript:
	-rm -rf PostScript/

clean-pdf:
	-rm -rf PDF/
endif

# zmazanie docasnych suborov vytvorenych LaTeXom
ifdef OUTPUT
clean-tex-logs:
	@for OUT in $(OUTPUT); \
	do \
		file="$${OUT%.ps}"; \
		file_list=""; \
		for i in $${file%.pdf}{.aux,.brf,.log,.lof,.lot,.out,.toc,.dvi,.ps,.pdf} ; \
		do \
			file_list="$$file_list $$i"; \
		done; \
	done; \
	filelist="`echo $$file_list | awk -v RS=' ' '{print}' | sort -u | awk -v ORS=' ' '{print}'`"; \
	echo -en "[36mDeleting extensions `echo $$asdf{.aux,.brf,.log,.lof,.lot,.out,.toc,.dvi,.ps,.pdf} `[0m"; echo; \
	echo "rm -f $$filelist"; \
	rm -f $$filelist;
else
clean-tex-logs:
	@filelist="`ls *{.aux,.brf,.log,.lof,.lot,.out,.toc,.dvi,.ps,.pdf} 2>/dev/null`"; \
	if [ ! -z "$$filelist" ]; then \
		echo -en "[36mDeleting files `echo $$asdf{.aux,.brf,.log,.lof,.lot,.out,.toc,.dvi,.ps,.pdf} `[0m"; echo; \
		echo "rm -f $$filelist"; \
		rm -f $$filelist; \
	fi
endif

# zmazanie vytvorenych grafov
clean-graphs:
	@test -z "$(GRAPHS)" || \
	for i in "$(GRAPHS)" ; \
	do \
		echo "rm -f $$i"; rm -f $$i; \
	done \
# }}}

# Distribution {{{
ifdef DISTFILES
dist: distdir
	GZIP=$(GZIP_ENV) $(TAR) chozf $(distdir).tar.gz  $(distdir)
	@#BZIP=$(GZIP_ENV) $(TAR) chojf $(distdir).tar.bz2 $(distdir)
	-rm -rf $(distdir)
	@#-@banner="md5sum is: `md5sum $(distdir).tar.gz |tee md5sum.$(distdir)`"; \
	dashes=`echo "$$banner" | sed s/./=/g`; \
	echo "$$dashes"; \
	echo "$$banner"; \
	echo "$$dashes"
endif

distdir: $(DISTFILES)
	-rm -rf $(distdir)
	mkdir $(distdir)
	-chmod a+rx $(distdir)
	@here=`cd $(top_builddir) && pwd`; \
	top_distdir=`cd $(distdir) && pwd`; \
	distdir=`cd $(distdir) && pwd`; \
	umask 022; \
	for file in $(DISTFILES); do \
	  d=$(srcdir); \
	  if test -d $$d/$$file; then \
	    mkdir $(distdir)/$$file; \
	  else \
	    test -f $(distdir)/$$file \
	    || cp $$d/$$file $(distdir)/$$file || :; \
	  fi; \
	done

# }}}

# vim: ts=4 isk+=- ft=make
# vim600: fdm=marker fdc=3

